        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 28 <strong>control</strong><br>0,1,3,4,5,6,9,11,13,16,17,18,19,20,21,24,25,26,28,30,32,33,34,35,36,40,44,46';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 23 <br>2,7,8,10,12,14,15,22,23,27,29,31,37,38,39,41,42,43,45,47,48,49,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 28 <strong>control</strong><br>0,1,3,4,5,6,9,11,13,16,17,18,19,20,21,24,25,26,28,30,32,33,34,35,36,40,44,46';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 23 <br>2,7,8,10,12,14,15,22,23,27,29,31,37,38,39,41,42,43,45,47,48,49,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 28 <strong>control</strong><br>0,1,3,4,5,6,9,11,13,16,17,18,19,20,21,24,25,26,28,30,32,33,34,35,36,40,44,46';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 23 <br>2,7,8,10,12,14,15,22,23,27,29,31,37,38,39,41,42,43,45,47,48,49,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 28 <strong>control</strong><br>0,1,3,4,5,6,9,11,13,16,17,18,19,20,21,24,25,26,28,30,32,33,34,35,36,40,44,46';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 23 <br>2,7,8,10,12,14,15,22,23,27,29,31,37,38,39,41,42,43,45,47,48,49,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 28 <strong>control</strong><br>0,1,3,4,5,6,9,11,13,16,17,18,19,20,21,24,25,26,28,30,32,33,34,35,36,40,44,46';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260512 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 23 <br>2,7,8,10,12,14,15,22,23,27,29,31,37,38,39,41,42,43,45,47,48,49,50';}
}
